@@ -62,6 +62,7 @@ prFindRownameMatches <- function(rnames, vn, vars) {
 #'  length issues as there may be variables that are excluded from the
 #'  model for different reasons.
 #' @return vector
+#' @importFrom stats as.formula 
 #'
 #' @keywords internal
 prExtractOutcomeFromModel <- function(model, mf) {
@@ -96,9 +97,11 @@ prExtractOutcomeFromModel <- function(model, mf) {
 #' @param x The fitted model.
 #' @param terms_only Only use the right side of the equation by selecting the terms
 #' @param term.label Sometimes need to retrieve specific spline labels that are not among
-#'  the labels(terms(x))
+#'  the `labels(terms(x))`
 #' @return data.frame
+#' @importFrom stats get_all_vars
 #'
+#' @importFrom stats terms
 #' @keywords internal
 prGetModelData <- function(x, terms_only = FALSE, term.label) {
   # Extract the variable names
@@ -357,143 +360,8 @@ prGetStatistics <- function(x,
   return(total_table)
 }
 
-#' Gets the boundaries for a survival fit
-#'
-#' @param fit A survival model of either competing risk regression or cox regression type
-#' @param conf.int The interval of interest 0-1, see levels in confint()
-#' @param exp If the value should be in exponential form (default)
-#' @return A matrix with the columns:
-#' \item{beta}{The estimated coefficient}
-#' \item{p_val}{P-value}
-#' \item{low}{The lower confidence interval}
-#' \item{high}{The upper confidence interval}
-#' \item{order}{A column that later can be used in ordering}
-#'
-#' @keywords internal
-prGetFpDataFromSurvivalFit <- function(fit,
-                                       conf.int = 0.95,
-                                       exp = TRUE) {
-  # Get the p-value, I use the method in the
-  # print.cph -> prModFit from the rms package
-  Z <- coef(fit) / sqrt(diag(fit$var))
-  p_val <- signif(1 - pchisq(Z^2, 1), 5)
-  order <- rep(-1, length(beta))
-  ci <- confint(fit, level = conf.int)
 
-  if (exp) {
-    ret_matrix <- cbind(
-      beta = exp(coef(fit)),
-      p_val = p_val,
-      low = exp(ci[, 1]),
-      high = exp(ci[, 2]),
-      order = order
-    )
-  } else {
-    ret_matrix <- cbind(
-      beta = coef(fit),
-      p_val = p_val,
-      low = ci[, 1],
-      high = ci[, 2],
-      order = order
-    )
-  }
-
-  # Set the names of the rows
-  rownames(ret_matrix) <- names(fit$coef)
-
-  return(ret_matrix)
-}
-
-#' Gets the boundaries for a GLM fit that is poisson or quasipoisson based
-#'
-#' @param glm.fit A regression model
-#' @param conf.int The interval of interest 0-1, see levels in confint()
-#' @param exp If the value should be in exponential form (default)
-#' @return A matrix with the columns:
-#' \item{beta}{The estimated coefficient}
-#' \item{p_val}{P-value}
-#' \item{low}{The lower confidence interval}
-#' \item{high}{The upper confidence interval}
-#' \item{order}{A column that later can be used in ordering}
-#'
-#' @keywords internal
-prGetFpDataFromGlmFit <- function(glm.fit,
-                                  conf.int = 0.95,
-                                  exp = TRUE) {
-  summary_glm <- summary.glm(glm.fit)
-
-  # Extract the summary values of interest
-  summary_se <- summary_glm$coefficients[, colnames(summary_glm$coefficients) == "Std. Error"]
-  if ("quasipoisson" %in% glm.fit$family) {
-    summary_p_val <- summary_glm$coefficients[, colnames(summary_glm$coefficients) == "Pr(>|t|)"]
-  } else if ("poisson" %in% glm.fit$family) {
-    summary_p_val <- summary_glm$coefficients[, colnames(summary_glm$coefficients) == "Pr(>|z|)"]
-  } else {
-    stop("Type of analysis not prepared!")
-  }
-
-  order <- rep(-1, length(glm.fit$coefficients))
-  ci <- confint(glm.fit, level = conf.int)
-
-  if (exp) {
-    ret_matrix <- cbind(
-      beta = exp(coef(glm.fit)),
-      p_val = summary_p_val,
-      low = exp(ci[, 1]),
-      high = exp(ci[, 2]),
-      order = order
-    )
-  } else {
-    ret_matrix <- cbind(
-      beta = coef(glm.fit),
-      p_val = summary_p_val,
-      low = ci[, 1],
-      high = ci[, 2],
-      order = order
-    )
-  }
-
-  # Set the names of the rows
-  rownames(ret_matrix) <- names(glm.fit$coefficients)
-
-  # Remove the intercept
-  ret_matrix <- ret_matrix[names(glm.fit$coefficients) != "(Intercept)", ]
-
-  return(ret_matrix)
-}
-
-
-#' Gets the confidence interval, p-values,
-#' coefficients from a survival object
-#'
-#' @param model_fit A regression fit from CRR, coxph, cph object
-#' @param conf.int The interval of interest 0-1, see levels in confint()
-#' @param exp If the value should be in exponential form (default)
-#' @return A matrix with the columns:
-#' \item{beta}{The estimated coefficient}
-#' \item{p_val}{P-value}
-#' \item{low}{The lower confidence interval}
-#' \item{high}{The upper confidence interval}
-#' \item{order}{A column that later can be used in ordering}
-#'
-#' @keywords internal
-prGetFpDataFromFit <- function(model_fit,
-                               conf.int = 0.95,
-                               exp = TRUE) {
-  # Get the estimates, confidence intervals and the p_values
-  if (any(class(model_fit) %in% "coxph") ||
-    any(class(model_fit) %in% "crr")) {
-    sd <- prGetFpDataFromSurvivalFit(fit = model_fit, conf.int = conf.int, exp = exp)
-  } else if (any(class(model_fit) %in% "glm")) {
-    sd <- prGetFpDataFromGlmFit(glm.fit = model_fit, conf.int = conf.int, exp = exp)
-  } else {
-    stop(paste("Unknown fit class type:", class(model_fit)))
-  }
-
-  return(sd)
-}
-
-#' A functuon for converting a useNA variable
+#' A function for converting a useNA variable
 #'
 #' The variable is suppose to be directly compatible with
 #' table(..., useNA = useNA). It throughs an error
